@@ -179,10 +179,17 @@ class CommonBrowserView(BrowserView):
         if event.portal_type != 'Event' and event.portal_type != 'Media Event':
             return ""
         
-        samedate = event.start().strftime('%d - %m - %Y') == event.end().strftime('%d - %m - %Y')
+        if event.start() is None or event.end() is None:
+            if event.start() is None and event.end() is None:
+                return ""
+            else:
+                samedate = True
+        else:
+            samedate = event.start().strftime('%d - %m - %Y') == event.end().strftime('%d - %m - %Y')
+            
         finalDatesFmt = '<div class="dates %(class)s"><span class="dateText">%(dates)s %(hours)s</span></div>'
         
-        dates = "%s"%(samedate and event.start().strftime('%A, %d %B %Y') or "%s to %s"%(event.start().strftime('%A, %d %B %Y'), event.end().strftime('%A, %d %B %Y')))
+        dates = "%s"%(samedate and (event.start() is not None and event.start().strftime('%A, %d %B %Y') or event.end().strftime('%A, %d %B %Y')) or "%s to %s"%(event.start().strftime('%A, %d %B %Y'), event.end().strftime('%A, %d %B %Y')))
         
         openingHour = event.start().strftime('%H:%M')
         closingHour = event.end().strftime('%H:%M')
@@ -410,6 +417,11 @@ class SearchView(CommonBrowserView, Search):
     Adding to Search view
     """
 
+class BlogView(FolderListing):
+    """
+    Adding to Blog view
+    """
+
 class Footer(FooterViewlet):
     """
     helper classes for footer
